@@ -260,6 +260,10 @@ sub new_ipaddr {
                                                : SILK_BAG_FIELD_ANY_IPv4);
 }
 
+sub new_ipv4addr {
+  shift->new(@_, key_type => SILK_BAG_FIELD_ANY_IPv4);
+}
+
 sub new_integer { shift->new(@_, key_type => SILK_BAG_FIELD_CUSTOM) }
 
 sub get_info {
@@ -1240,6 +1244,10 @@ Valid key and counter types are:
 Creates a bag using 'any-ipv6' if SILK_IPV6_ENABLED is true, otherwise
 using 'any-ipv4'.
 
+=item new_ipv4addr()
+
+Creates a bag using 'any-ipv4', regardless of SILK_IPV6_ENABLED.
+
 =item new_integer()
 
 Returns a bag using the 'custom' key type (integer bag).
