@@ -41,7 +41,7 @@
  * Convert a string to an int64_t/uint64_t.
  */
 
-groknum_err_t
+static groknum_err_t
 strtoint64(pTHX_ const char *s, int base, int sign, uint64_t *u64)
 {
 	uint64_t acc = 0;
